import 'dart:async';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-image-widget-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkCardImageWithBottomWidget extends StatefulWidget {
  const VgkCardImageWithBottomWidget(
      {Key key,
      this.mainScreenAnimationController,
      this.mainScreenAnimation,
      this.data})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final VgkCardImageWidgetModel data;
  @override
  _VgkCardImageWithBottomWidgetState createState() =>
      _VgkCardImageWithBottomWidgetState();
}

class _VgkCardImageWithBottomWidgetState
    extends State<VgkCardImageWithBottomWidget> with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform:
                VgkProGamingTheme.subTransform(widget.mainScreenAnimation),
            child: Container(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
              child: ClipRRect(
                child: Stack(
                  children: <Widget>[
                    Column(
                      children: <Widget>[
                        AspectRatio(
                          aspectRatio: 2,
                          child: CachedNetworkImage(
                            imageUrl: widget.data.src,
                            fit: BoxFit.fill,
                            progressIndicatorBuilder:
                                (context, url, downloadProgress) =>
                                    CircularProgressIndicator(
                                        value: downloadProgress.progress),
                            errorWidget: (context, url, error) =>
                                Icon(Icons.error),
                          ),
                        ),
                        ButtonBar(
                          alignment: MainAxisAlignment.spaceAround,
                          buttonHeight: 52.0,
                          buttonMinWidth: 90.0,
                          children: <Widget>[
                            TextButton(
                              style: VgkProGamingTheme.flatButtonStyle,
                              onPressed: () {},
                              child: Column(
                                children: <Widget>[
                                  Icon(Icons.arrow_downward),
                                  Padding(
                                    padding: const EdgeInsets.symmetric(
                                        vertical: 2.0),
                                  ),
                                  Text('Open'),
                                ],
                              ),
                            ),
                            TextButton(
                              style: VgkProGamingTheme.flatButtonStyle,
                              onPressed: () {},
                              child: Column(
                                children: <Widget>[
                                  Icon(Icons.arrow_upward),
                                  Padding(
                                    padding: const EdgeInsets.symmetric(
                                        vertical: 2.0),
                                  ),
                                  Text('Close'),
                                ],
                              ),
                            ),
                            TextButton(
                              style: VgkProGamingTheme.flatButtonStyle,
                              onPressed: () {},
                              child: Column(
                                children: <Widget>[
                                  Icon(Icons.swap_vert),
                                  Padding(
                                    padding: const EdgeInsets.symmetric(
                                        vertical: 2.0),
                                  ),
                                  Text('Toggle'),
                                ],
                              ),
                            ),
                          ],
                        )
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}
